/* 
 * File:   EEPROM.h
 * Author: chengo_cc
 *
 * Created on 17 December 2015, 12:46 PM
 */

#ifndef EEPROM_H
//#include "EEPROM_prototypes.h"
//------------------------------------------------------------------------------
#define WREN    0x06            //Write Enable
#define WRDI    0x04            //Write Disable
#define WRITE   0x02
#define READ    0x03
#define RDSR    0x05            //Read Status Register
//------------------------------------------------------------------------------
char EEPROM_status(void)
{
  char status = 0 ;          

  CS = 0;
  SPI_TX(RDSR);               //Intsruction: Read Status register of the EEPROM.
  status = SPI_RX() ;
  CS = 1;

  return status;
}
//------------------------------------------------------------------------------
/*LSB is Write-In-Process (WIP) bit. When Set, a write is in progress, when Clear, no write is in progress*/
char EEPROM_busy(void)
{
  char busy = (EEPROM_status() & 0x01) ? 1 : 0;

  return busy;
}
//------------------------------------------------------------------------------
/*Bit 2 is the Write Enable Latch (WEL) bit and indicates the status of the write enable latch*/
char EEPROM_writeEnable(void)
{
  char writeEnable = (EEPROM_status() & 0x02) ? 1 : 0;

  return writeEnable;
}
//------------------------------------------------------------------------------
char EEPROM_read(unsigned short address) //short is 16 bits wide
{
   char read = 0;

   while(EEPROM_busy() == 1); //Wait for previous Write/Read operations to finish

   CS = 0;
   SPI_TX(READ);
   SPI_TX(address>>8); //Upper Byte
   SPI_TX(address);    //Lower Byte
   read = SPI_RX();
   CS = 1;

   return read;
}
//------------------------------------------------------------------------------
void EEPROM_write(unsigned short address,unsigned char data)
{
   while(EEPROM_busy() == 1);

   //Set write enable latch
   CS = 0;
   SPI_TX(WREN);
   CS = 1; //Latch-Enabled. use isWriteEn() to verify

   //Start Write sequence(only occurs when/if Write latch is Enanled)
   CS = 0;
   SPI_TX(WRITE);
   SPI_TX(address>>8);
   SPI_TX(address);
   SPI_TX(data);
   CS = 1;
}
/*------------------------------------------------------------------------------
            NB: short is of size 2 Bytes, and char is a byte wide
------------------------------------------------------------------------------*/
#define	EEPROM_H

#ifdef	__cplusplus
extern "C" {
#endif




#ifdef	__cplusplus
}
#endif

#endif	/* EEPROM_H */

